@@ -34,12 +34,8 @@ ContingencyTableTest <- R6Class(
         },
 
         .calculate_statistic = function() {
-            r <- nrow(private$.data)
-            c <- ncol(private$.data)
-
             private$.statistic <- table_pmt(
-                rep.int(rep.int(seq_len(r) - 1, c), private$.data),
-                rep.int(seq_len(c) - 1, .colSums(private$.data, r, c)),
+                private$.data,
                 private$.statistic_func,
                 if (private$.type == "permu") private$.n_permu else NA_real_,
                 isTRUE(getOption("LearnNonparam.pmt_progress"))
