@@ -2,11 +2,11 @@
 #' 
 #' @description Performs two-sample Kolmogorov-Smirnov test on samples.
 #' 
-#' @aliases twosample.ks
+#' @aliases distribution.ks
 #' 
 #' @examples
 #' pmt(
-#'     "twosample.ks", n_permu = 0
+#'     "distribution.ks", n_permu = 0
 #' )$test(Table2.8.1)$print()
 #' 
 #' @export
@@ -16,7 +16,7 @@
 
 KolmogorovSmirnov <- R6Class(
     classname = "KolmogorovSmirnov",
-    inherit = TwoSampleTest,
+    inherit = TwoSampleDistributionTest,
     cloneable = FALSE,
     public = list(
         #' @description Create a new `KolmogorovSmirnov` object.
@@ -25,8 +25,9 @@ KolmogorovSmirnov <- R6Class(
         #' 
         #' @return A `KolmogorovSmirnov` object.
         initialize = function(
-            n_permu = 1e4
+            alternative = c("two_sided", "less", "greater"), n_permu = 1e4
         ) {
+            self$alternative <- alternative
             self$n_permu <- n_permu
         }
     ),
@@ -34,21 +35,19 @@ KolmogorovSmirnov <- R6Class(
         .name = "Two-Sample Kolmogorov-Smirnov Test",
 
         .define = function() {
-            private$.statistic_func <- function(x, y) {
-                m <- length(x)
-                n <- length(y)
-
-                geq_m <- -1 / n
-                leq_m <- rep.int(1 / m, m + n)
-
-                function(x, y) {
-                    max(abs(cumsum(`[<-`(leq_m, order(c(x, y)) > m, geq_m))))
-                }
+            private$.statistic_func <- function(...) {
+                switch(private$.alternative,
+                    two_sided = function(f, g) max(abs(f - g)),
+                    less = function(f, g) max(g - f),
+                    greater = function(f, g) max(f - g)
+                )
             }
         },
 
         .calculate_side = function() {
             private$.side <- "r"
-        }
+        },
+
+        .on_alternative_change = function() private$.calculate()
     )
 )
\ No newline at end of file
